==> firefox-62.0b18.source.tar.xz: firefox-62.0/netwerk/dns/DNSRequestParent.h <==
/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set sw=2 ts=8 et tw=80 : */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#ifndef mozilla_net_DNSRequestParent_h
#define mozilla_net_DNSRequestParent_h

#include "mozilla/net/PDNSRequestParent.h"
#include "nsIDNSService.h"
#include "nsIDNSListener.h"

namespace mozilla {
namespace net {

class DNSRequestParent
  : public PDNSRequestParent
  , public nsIDNSListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDNSLISTENER

  DNSRequestParent();

  void DoAsyncResolve(const nsACString  &hostname,
                      const OriginAttributes &originAttributes,
                      uint32_t flags);

  // Pass args here rather than storing them in the parent; they are only
  // needed if the request is to be canceled.
  mozilla::ipc::IPCResult RecvCancelDNSRequest(const nsCString& hostName,
                                               const OriginAttributes& originAttributes,
                                               const uint32_t& flags,
                                               const nsresult& reason) override;
  mozilla::ipc::IPCResult Recv__delete__() override;

protected:
  virtual void ActorDestroy(ActorDestroyReason why) override;
private:
  virtual ~DNSRequestParent() = default;

  uint32_t mFlags;
  bool mIPCClosed;  // true if IPDL channel has been closed (child crash)
};

} // namespace net
} // namespace mozilla

#endif // mozilla_net_DNSRequestParent_h

==> firefox-65.0.1.source.tar.xz: firefox-65.0.1/netwerk/dns/DNSRequestParent.h <==
/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set sw=2 ts=8 et tw=80 : */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#ifndef mozilla_net_DNSRequestParent_h
#define mozilla_net_DNSRequestParent_h

#include "mozilla/net/PDNSRequestParent.h"
#include "nsIDNSService.h"
#include "nsIDNSListener.h"

namespace mozilla {
namespace net {

class DNSRequestParent : public PDNSRequestParent, public nsIDNSListener {
 public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDNSLISTENER

  DNSRequestParent();

  void DoAsyncResolve(const nsACString& hostname,
                      const OriginAttributes& originAttributes, uint32_t flags);

  // Pass args here rather than storing them in the parent; they are only
  // needed if the request is to be canceled.
  mozilla::ipc::IPCResult RecvCancelDNSRequest(
      const nsCString& hostName, const uint16_t& type,
      const OriginAttributes& originAttributes, const uint32_t& flags,
      const nsresult& reason) override;
  mozilla::ipc::IPCResult Recv__delete__() override;

 protected:
  virtual void ActorDestroy(ActorDestroyReason why) override;

 private:
  virtual ~DNSRequestParent() = default;

  uint32_t mFlags;
  bool mIPCClosed;  // true if IPDL channel has been closed (child crash)
};

}  // namespace net
}  // namespace mozilla

#endif  // mozilla_net_DNSRequestParent_h
